@@ -26,7 +26,7 @@ $ENV{A_PLUGIN_PATH}="$plugins_dir/";
 $oldClasspath = $ENV{CLASSPATH};
 
 
-$ENV{"CLASSPATH"}="$plugins_dir:$plugins_dir/dstore_extra_server.jar:$plugins_dir/dstore_core.jar:$plugins_dir/dstore_miners.jar:$plugins_dir/clientserver.jar:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.7.0.v20110110.jar:$plugins_dir/org.eclipse.equinox.common_3.6.0.v20110523.jar:$plugins_dir/org.eclipse.core.filesystem_1.3.100.v20110423-0524.jar:$plugins_dir/com.ibm.icu.base_4.4.2.v20110208.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/upcparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/spawner.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v201004271650.jar:$oldClasspath";
+$ENV{"CLASSPATH"}="$plugins_dir:$plugins_dir/dstore_extra_server.jar:$plugins_dir/dstore_core.jar:$plugins_dir/dstore_miners.jar:$plugins_dir/clientserver.jar:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.8.0.v20120521-2346.jar:$plugins_dir/org.eclipse.equinox.common_3.6.100.v20120522-1841.jar:$plugins_dir/org.eclipse.core.filesystem_1.3.200.v20120522-2012.jar:$plugins_dir/com.ibm.icu.base_4.4.2.v20110831.jar:$plugins_dir/org.eclipse.text_3.5.200.v20120523-1310.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/upcparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/spawner.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v201004271650.jar:$oldClasspath";
 
 if (!defined($timeout))
 {
